@@ -233,9 +233,68 @@ setMethod("dbWriteTable", c("MariaDBConnection", "character", "character"),
 #' @export
 #' @rdname mariadb-tables
 setMethod("dbListTables", "MariaDBConnection", function(conn, ...) {
-  dbGetQuery(conn, "SHOW TABLES")[[1]]
+  # DATABASE(): https://stackoverflow.com/a/8096574/946850
+  dbGetQuery(
+    conn,
+    paste0(
+      "SELECT table_name FROM INFORMATION_SCHEMA.tables\n",
+      "WHERE table_schema = DATABASE()"
+    )
+  )[[1]]
 })
 
+
+#' @export
+#' @inheritParams DBI::dbListObjects
+#' @rdname mariadb-tables
+setMethod("dbListObjects", c("MariaDBConnection", "ANY"), function(conn, prefix = NULL, ...) {
+  query <- NULL
+  if (is.null(prefix)) {
+    # DATABASE(): https://stackoverflow.com/a/8096574/946850
+    query <- paste0(
+      "SELECT NULL AS `schema`, table_name AS `table` FROM INFORMATION_SCHEMA.tables\n",
+      "WHERE table_schema = DATABASE()\n",
+      "UNION ALL\n",
+      "SELECT DISTINCT table_schema AS `schema`, NULL AS `table` FROM INFORMATION_SCHEMA.tables"
+    )
+  } else {
+    unquoted <- dbUnquoteIdentifier(conn, prefix)
+    is_prefix <- vlapply(unquoted, function(x) { "schema" %in% names(x@name) && !("table" %in% names(x@name)) })
+    schemas <- vcapply(unquoted[is_prefix], function(x) x@name[["schema"]])
+    if (length(schemas) > 0) {
+      schema_strings <- dbQuoteString(conn, schemas)
+      query <- paste0(
+        "SELECT table_schema AS `schema`, table_name AS `table` FROM INFORMATION_SCHEMA.tables\n",
+        "WHERE ",
+        "(table_schema IN (", paste(schema_strings, collapse = ", "), "))"
+      )
+    }
+  }
+
+  if (is.null(query)) {
+    res <- data.frame(schema = character(), table = character(), stringsAsFactors = FALSE)
+  } else {
+    res <- dbGetQuery(conn, query)
+  }
+
+  is_prefix <- !is.na(res$schema) & is.na(res$table)
+  tables <- Map(res$schema, res$table, f = as_table)
+
+  ret <- data.frame(
+    table = I(unname(tables)),
+    is_prefix = is_prefix,
+    stringsAsFactors = FALSE
+  )
+  ret
+})
+
+as_table <- function(schema, table, naked_table = NULL) {
+  args <- c(schema = schema, table = table, table = naked_table)
+  # Also omits NA args
+  args <- args[!is.na(args) & args != ""]
+  do.call(Id, as.list(args))
+}
+
 #' @export
 #' @rdname mariadb-tables
 setMethod("dbExistsTable", c("MariaDBConnection", "character"),
@@ -306,6 +365,7 @@ setMethod("dbDataType", "MariaDBDriver", function(dbObj, obj, ...) {
   if (inherits(obj, "POSIXct")) return("DATETIME")
   if (inherits(obj, "Date")) return("DATE")
   if (inherits(obj, "difftime")) return("TIME")
+  if (inherits(obj, "integer64")) return("BIGINT")
   if (is.data.frame(obj)) return(callNextMethod(dbObj, obj))
 
   switch(typeof(obj),
